@@ -2,15 +2,98 @@ use poem::{
     endpoint::{make_sync, BoxEndpoint},
     middleware::CookieJarManager,
     web::cookie::CookieKey,
-    Endpoint, EndpointExt, FromRequest, IntoEndpoint, IntoResponse, Request, Response, Route,
+    Endpoint, EndpointExt, IntoEndpoint, Request, Response, Route,
 };
 
 use crate::{
     base::UrlQuery,
-    registry::{Document, MetaInfo, MetaServer, Registry},
+    registry::{Document, MetaInfo, MetaLicense, MetaServer, Registry},
     OpenApi,
 };
 
+/// An object representing a Server.
+#[derive(Debug, Clone)]
+pub struct ServerObject {
+    url: String,
+    description: Option<String>,
+}
+
+impl From<String> for ServerObject {
+    fn from(url: String) -> Self {
+        Self::new(url)
+    }
+}
+
+impl From<&str> for ServerObject {
+    fn from(url: &str) -> Self {
+        Self::new(url.to_string())
+    }
+}
+
+impl From<&str> for LicenseObject {
+    fn from(name: &str) -> Self {
+        Self::new(name.to_string())
+    }
+}
+
+impl ServerObject {
+    /// Create a server object by url.
+    pub fn new(url: impl Into<String>) -> ServerObject {
+        Self {
+            url: url.into(),
+            description: None,
+        }
+    }
+
+    /// Specifies an string describing the host designated by the URL.
+    pub fn description(self, description: impl Into<String>) -> Self {
+        Self {
+            description: Some(description.into()),
+            ..self
+        }
+    }
+}
+
+/// A license information for the exposed API.
+pub struct LicenseObject {
+    name: String,
+    identifier: Option<String>,
+    url: Option<String>,
+}
+
+impl From<String> for LicenseObject {
+    fn from(name: String) -> Self {
+        Self::new(name)
+    }
+}
+
+impl LicenseObject {
+    /// Create a license object by name.
+    pub fn new(name: impl Into<String>) -> LicenseObject {
+        Self {
+            name: name.into(),
+            identifier: None,
+            url: None,
+        }
+    }
+
+    /// Specifies an [`SPDX`](https://spdx.org/spdx-specification-21-web-version#h.jxpfx0ykyb60) license expression for the API.
+    pub fn identifier(self, identifier: impl Into<String>) -> Self {
+        Self {
+            identifier: Some(identifier.into()),
+            ..self
+        }
+    }
+
+    /// Specifies a URL to the license used for the API.
+    pub fn url(self, url: impl Into<String>) -> Self {
+        Self {
+            url: Some(url.into()),
+            ..self
+        }
+    }
+}
+
 /// An OpenAPI service for Poem.
 pub struct OpenApiService<T> {
     api: T,
@@ -29,6 +112,8 @@ impl<T> OpenApiService<T> {
                 title: title.into(),
                 description: None,
                 version: version.into(),
+                terms_of_service: None,
+                license: None,
             },
             servers: Vec::new(),
             cookie_key: None,
@@ -42,28 +127,35 @@ impl<T> OpenApiService<T> {
         self
     }
 
+    /// Sets a URL to the Terms of Service for the API.
+    pub fn terms_of_service(mut self, url: impl Into<String>) -> Self {
+        self.info.terms_of_service = Some(url.into());
+        self
+    }
+
     /// Appends a server to the API container.
     ///
     /// Reference: <https://github.com/OAI/OpenAPI-Specification/blob/main/versions/3.1.0.md#serverObject>
     #[must_use]
-    pub fn server(mut self, url: impl Into<String>) -> Self {
+    pub fn server(mut self, server: impl Into<ServerObject>) -> Self {
+        let server = server.into();
         self.servers.push(MetaServer {
-            url: url.into(),
-            description: None,
+            url: server.url,
+            description: server.description,
         });
         self
     }
 
-    /// Appends a server and description to the API container.
+    /// Specifies the license information for the exposed API.
+    ///
+    /// Reference: https://github.com/OAI/OpenAPI-Specification/blob/main/versions/3.1.0.md#license-object
     #[must_use]
-    pub fn server_with_description(
-        mut self,
-        url: impl Into<String>,
-        description: impl Into<String>,
-    ) -> Self {
-        self.servers.push(MetaServer {
-            url: url.into(),
-            description: Some(description.into()),
+    pub fn license(mut self, license: impl Into<LicenseObject>) -> Self {
+        let license = license.into();
+        self.info.license = Some(MetaLicense {
+            name: license.name,
+            identifier: license.identifier,
+            url: license.url,
         });
         self
     }
@@ -142,30 +234,22 @@ impl<T: OpenApi> IntoEndpoint for OpenApiService<T> {
     type Endpoint = BoxEndpoint<'static, Response>;
 
     fn into_endpoint(self) -> Self::Endpoint {
-        async fn extract_query(next: impl Endpoint, mut req: Request) -> impl IntoResponse {
-            let query: poem::web::Query<Vec<(String, String)>> =
-                FromRequest::from_request(&req, &mut Default::default())
-                    .await
-                    .unwrap_or_default();
-            req.extensions_mut().insert(UrlQuery(query.0));
-            next.call(req).await
+        async fn extract_query(mut req: Request) -> Request {
+            let url_query: Vec<(String, String)> = req.params().unwrap_or_default();
+            req.extensions_mut().insert(UrlQuery(url_query));
+            req
         }
 
-        match self.cookie_key {
-            Some(key) => self
-                .api
-                .add_routes(Route::new())
-                .with(CookieJarManager::with_key(key))
-                .around(extract_query)
-                .map_to_response()
-                .boxed(),
-            None => self
-                .api
-                .add_routes(Route::new())
-                .with(CookieJarManager::new())
-                .around(extract_query)
-                .map_to_response()
-                .boxed(),
-        }
+        let cookie_jar_manager = match self.cookie_key {
+            Some(key) => CookieJarManager::with_key(key),
+            None => CookieJarManager::new(),
+        };
+
+        self.api
+            .add_routes(Route::new())
+            .with(cookie_jar_manager)
+            .before(extract_query)
+            .map_to_response()
+            .boxed()
     }
 }
