@@ -7,6 +7,10 @@ mod floats;
 mod hashmap;
 mod integers;
 mod optional;
+mod regex;
 mod slice;
 mod string;
+mod uri;
+#[cfg(feature = "uuid")]
+mod uuid;
 mod vec;
